# Generated by Django 4.0.3 on 2022-03-23 10:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authorities', '0003_authority_email'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authority',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Name'),
        ),
        migrations.AlterUniqueTogether(
            name='authority',
            unique_together={('name', 'kind')},
        ),
    ]
